@@ -1,5 +1,5 @@
 /*  SMTUBE2, a small YouTube browser for SMPlayer
-    Copyright (C) 2015-2019 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2015-2020 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -44,8 +44,7 @@
 #include "links.h"
 #include "desktopinfo.h"
 
-#ifdef YT_USE_YTSIG
-#include "ytsig.h"
+#ifdef CODEDOWNLOADER
 #include "codedownloader.h"
 #endif
 
@@ -64,34 +63,22 @@ BrowserWindow::BrowserWindow(const QString & config_path, QWidget * parent, Qt::
 #ifdef D_BUTTON
 	, add_download_button(false)
 #endif
-#ifdef YT_USE_YTSIG
-	, codedownloader(0)
-#endif
 {
 	setWindowTitle("SMTube");
 	setWindowIcon(QPixmap(":/icons/smtube.png"));
-	home_page = "http://www.tonvid.com/";
 
 	settings = new QSettings(config_path + "/smtube2.ini", QSettings::IniFormat, this);
 
 	ryu = new RetrieveYoutubeUrl(this);
 	connect(ryu, SIGNAL(gotPreferredUrl(const QString &, int)), this, SLOT(openYTUrl(const QString &, int)));
-	connect(ryu, SIGNAL(signatureNotFound(const QString &)), this, SLOT(showErrorSignatureNotFound(const QString &)));
-	connect(ryu, SIGNAL(noSslSupport()), this, SLOT(showErrorNoSslSupport()));
 	connect(ryu, SIGNAL(gotEmptyList()), this, SLOT(showErrorEmptyList()));
+	connect(ryu, SIGNAL(processFailedToStart()), this, SLOT(YTFailedToStart()));
 
 	ryua = new RetrieveYoutubeUrl(this);
 	ryua->setUseDASH(true);
-	connect(ryua, SIGNAL(gotUrls(const QMap<int, QString>&)), this, SLOT(openYTAudioUrl(const QMap<int, QString>&)));
-	connect(ryua, SIGNAL(signatureNotFound(const QString &)), this, SLOT(showErrorSignatureNotFound(const QString &)));
-	connect(ryua, SIGNAL(noSslSupport()), this, SLOT(showErrorNoSslSupport()));
+	connect(ryua, SIGNAL(gotPreferredUrl(const QString &, int)), this, SLOT(openYTAudioUrl(const QString &, int)));
 	connect(ryua, SIGNAL(gotEmptyList()), this, SLOT(showErrorEmptyList()));
-
-	#ifdef YT_USE_SIG
-	QSettings * sigset = new QSettings(config_path + "/sig.ini", QSettings::IniFormat, this);
-	ryu->setSettings(sigset);
-	ryua->setSettings(sigset);
-	#endif
+	connect(ryua, SIGNAL(processFailedToStart()), this, SLOT(YTFailedToStart()));
 
 	QNetworkProxyFactory::setUseSystemConfiguration(true);
 
@@ -175,18 +162,16 @@ BrowserWindow::BrowserWindow(const QString & config_path, QWidget * parent, Qt::
 
 	QMenu * helpMenu = menuBar()->addMenu(tr("&Help"));
 
-#ifdef YT_USE_YTSIG
-	QAction * updateCodeAct = new QAction(tr("&Update the YouTube code"), this);
+#ifdef CODEDOWNLOADER
+	#if defined(Q_OS_WIN) && !defined(PORTABLE_APP)
+	QAction * updateCodeAct = new QAction(tr("&Update YouTube playback support"), this);
+	#else
+	QAction * updateCodeAct = new QAction(tr("&Install / Update YouTube playback support"), this);
+	#endif
 	connect(updateCodeAct, SIGNAL(triggered()), this, SLOT(updateYTCode()));
 	helpMenu->addAction(updateCodeAct);
 #endif
 
-#ifdef SHOW_RELEASE_DIALOG
-	QAction * aboutReleaseAct = new QAction(tr("About this &release"), this);
-	connect(aboutReleaseAct, SIGNAL(triggered()), this, SLOT(showAboutRelease()));
-	helpMenu->addAction(aboutReleaseAct);
-#endif
-
 	QAction * aboutAct = new QAction(tr("&About SMTube"), this);
 	connect(aboutAct, SIGNAL(triggered()), this, SLOT(showAbout()));
 	helpMenu->addAction(aboutAct);
@@ -213,6 +198,14 @@ BrowserWindow::~BrowserWindow() {
 	saveConfig();
 }
 
+QString BrowserWindow::homePageUrl() {
+#ifdef USE_SITES
+	return sites.currentSite().homeUrl();
+#else
+	return "http://www.tonvid.com/";
+#endif
+}
+
 void BrowserWindow::viewToolbar(bool b) {
 	qDebug() << "BrowserWindow::viewToolbar:" << b;
 	toolbar->setVisible(b);
@@ -246,7 +239,12 @@ void BrowserWindow::search(const QString & term) {
 		search_term = search_term.replace("https://", "");
 	}
 
-	QString q = home_page + "search.php?q=" + search_term;
+#ifdef USE_SITES
+	QString q = sites.currentSite().searchUrl();
+	q.replace("SEARCHTERM", search_term);
+#else
+	QString q = homePageUrl() + "search.php?q=" + search_term;
+#endif
 	loadUrl(QUrl(q));
 }
 
@@ -372,10 +370,6 @@ void BrowserWindow::fetchVideoUrl(RetrieveYoutubeUrl * ry, const QUrl & url, int
 	}
 	#endif
 
-	#ifdef YT_USE_YTSIG
-	YTSig::setScriptFile(script_file);
-	#endif
-
 	ry->setPreferredResolution((RetrieveYoutubeUrl::Resolution) resolution);
 	ry->fetchPage(url.toString());
 }
@@ -487,7 +481,7 @@ void BrowserWindow::openYTUrl(QString title, QString extension, const QString &
 }
 
 void BrowserWindow::openYTUrl(const QString & url, int itag) {
-	openYTUrl(ryu->urlTitle(), ryu->extensionForItag(itag), url);
+	openYTUrl(ryu->videoTitle(), ryu->extensionForItag(itag), url);
 }
 
 void BrowserWindow::openAudioWith(const QString & player, const QUrl & url) {
@@ -508,81 +502,40 @@ void BrowserWindow::openAudioWith(const QString & player, const QUrl & url) {
 	}
 }
 
-void BrowserWindow::openYTAudioUrl(const QMap<int, QString>& url_map) {
-	Q_UNUSED(url_map);
+void BrowserWindow::openYTAudioUrl(const QString &, int) {
 	qDebug() << "BrowserWindow::openYTAudioUrl";
 
-	int itag = ryua->selectedQuality();
+	int itag = ryua->selectedAudioQuality();
 	QString url = ryua->selectedAudioUrl();
 
 	qDebug() << "BrowserWindow::openYTAudioUrl: url:" << url << "itag:" << itag;
 
 	if (!url.isEmpty()) {
-		openYTUrl(ryua->urlTitle(), ryu->extensionForItag(itag), url);
+		openYTUrl(ryua->videoTitle(), ryu->extensionForItag(itag), url);
 	}
 }
 
-void BrowserWindow::showErrorNoSslSupport() {
-	qDebug() << "BrowserWindow::showErrorNoSslSupport";
-	QMessageBox::warning(this, tr("Connection failed"),
-		tr("The video you requested needs to open a HTTPS connection.") +"<br>"+
-		tr("Unfortunately the OpenSSL component, required for it, is not available in your system."));
-}
-
 void BrowserWindow::showErrorEmptyList() {
 	qDebug() << "showErrorEmptyList";
+
+#ifdef CODEDOWNLOADER
+	CodeDownloader::askAndDownload(this, CodeDownloader::UrlNotFound);
+#else
 	QMessageBox::warning(this, tr("No video found"),
 		tr("It wasn't possible to find the URL for this video."));
+#endif
 }
 
-void BrowserWindow::showErrorSignatureNotFound(const QString & title) {
-	qDebug() << "YTDialog::showErrorSignatureNotFound:" << title;
-
-	QString t = title;
-	t.replace(" - YouTube", "");
-
-	#ifdef YT_USE_YTSIG
-	int ret = QMessageBox::question(this, tr("Problems with YouTube"),
-				tr("Unfortunately due to changes in YouTube, the video '%1' can't be played.").arg(t) + "<br><br>" +
-				tr("Do you want to update the YouTube code? This may fix the problem."),
-				QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes);
-	if (ret == QMessageBox::Yes) {
-		updateYTCode();
-	}
-	#else
-	QMessageBox::warning(this, tr("Problems with YouTube"),
-		tr("Unfortunately due to changes in YouTube, the video '%1' can't be played.").arg(t) + "<br><br>" +
-		tr("Maybe updating this application could fix the problem."));
-	#endif
-}
-
-#ifdef YT_USE_YTSIG
+#ifdef CODEDOWNLOADER
 void BrowserWindow::updateYTCode() {
 	qDebug() << "BrowserWindow::updateYTCode";
-
-	if (!codedownloader) {
-		codedownloader = new CodeDownloader(this);
-	}
-	codedownloader->saveAs(script_file);
-	codedownloader->show();
-	codedownloader->download(QUrl(URL_YT_CODE));
+	CodeDownloader::askAndDownload(this);
 }
 #endif
 
-#ifdef SHOW_RELEASE_DIALOG
-void BrowserWindow::showAboutRelease() {
-	QMessageBox::about(this, tr("About this release"),
-		"<p>"+ tr("Due to changes in YouTube, the old SMTube doesn't work anymore.") + "<p>"+
-		tr("This is a new version of SMTube, written from scratch.") +" "+
-		tr("Some functionality is not available yet.")
-#ifdef YT_USE_YTSIG
-		+ "<p><b>"+ tr("Important:") + "</b><br>"+
-		tr("If the VEVO videos fail to play, please use the option %1 in the Help menu.")
-			.arg("<i><b>" + tr("Update the YouTube code") + "</b></i>")
-#endif
-	);
+void BrowserWindow::YTFailedToStart() {
+	CodeDownloader::askAndDownload(this, CodeDownloader::FailedToRun);
 }
-#endif
 
 void BrowserWindow::showAbout() {
 	About d(this);
@@ -598,6 +551,12 @@ void BrowserWindow::showConfigDialog() {
 	d.setDefaultPlayers(players.defaultPlayers());
 	#endif
 
+	#ifdef USE_SITES
+	d.setSites(sites.allSites());
+	d.setCurrentSite(sites.current());
+	bool needs_refresh = false;
+	#endif
+
 	#ifdef D_BUTTON
 	d.setAddDownloadButton(add_download_button);
 	d.setExternalDownloadUrl(external_download_url);
@@ -616,6 +575,15 @@ void BrowserWindow::showConfigDialog() {
 		view->setPlayers(players.availablePlayers());
 		#endif
 
+		#ifdef USE_SITES
+		int current_site = d.currentSite();
+		if (current_site != sites.current()) {
+			sites.setCurrent(current_site);
+			needs_refresh = true;
+		}
+		sites.setAllSites(d.sites());
+		#endif
+
 		#ifdef D_BUTTON
 		add_download_button = d.addDownloadButton();
 		external_download_url = d.externalDownloadUrl();
@@ -628,6 +596,10 @@ void BrowserWindow::showConfigDialog() {
 		setStyle(d.style());
 		#endif
 	}
+
+	#ifdef USE_SITES
+	if (needs_refresh) loadHomePage();
+	#endif
 }
 
 void BrowserWindow::saveConfig() {
@@ -650,8 +622,6 @@ void BrowserWindow::saveConfig() {
 	settings->beginGroup("General");
 	settings->setValue("playback_resolution", preferred_resolution);
 	settings->setValue("user_agent", ryu->userAgent());
-	settings->setValue("use_https_main", ryu->useHttpsMain());
-	//settings->setValue("use_https_vi", ryu->useHttpsVi());
 
 #ifdef D_BUTTON
 	settings->setValue("add_download_button", add_download_button);
@@ -672,9 +642,19 @@ void BrowserWindow::saveConfig() {
 	settings->setValue("zoom", view->page()->mainFrame()->zoomFactor());
 	settings->endGroup();
 
+	settings->beginGroup("youtube-dl");
+	settings->setValue("ytdl_bin", ytdl_bin);
+	settings->setValue("override_format", ryu->userFormat());
+	settings->setValue("use_av1", ryu->isAv1Enabled());
+	settings->endGroup();
+
 #ifdef USE_PLAYERS
 	players.save(settings);
 #endif
+
+#ifdef USE_SITES
+	sites.save(settings);
+#endif
 }
 
 void BrowserWindow::loadConfig() {
@@ -707,8 +687,6 @@ void BrowserWindow::loadConfig() {
 	settings->beginGroup("General");
 	preferred_resolution = settings->value("playback_resolution", RetrieveYoutubeUrl::R360p).toInt();
 	ryu->setUserAgent(settings->value("user_agent", "").toString());
-	ryu->setUseHttpsMain(settings->value("use_https_main", false).toBool());
-	//ryu->setUseHttpsVi(settings->value("use_https_vi", false).toBool());
 
 #ifdef D_BUTTON
 	add_download_button = settings->value("add_download_button", false).toBool();
@@ -717,10 +695,6 @@ void BrowserWindow::loadConfig() {
 	external_download_url = settings->value("external_download_url", default_url).toString();
 #endif
 
-#ifdef SHOW_RELEASE_DIALOG
-	bool shown_notes = settings->value("shown_notes", false).toBool();
-	settings->setValue("shown_notes", true);
-#endif
 	settings->endGroup();
 
 	settings->beginGroup("browser");
@@ -744,6 +718,14 @@ void BrowserWindow::loadConfig() {
 
 	settings->endGroup();
 
+	settings->beginGroup("youtube-dl");
+	ytdl_bin = settings->value("ytdl_bin", "").toString();
+	ryu->setYtdlBin(ytdl_bin);
+	ryua->setYtdlBin(ytdl_bin);
+	ryu->setUserFormat(settings->value("override_format", "").toString());
+	ryu->enableAv1(settings->value("use_av1", false).toBool());
+	settings->endGroup();
+
 	#ifndef PORTABLE_APP
 	if (use_cache) {
 		#if QT_VERSION >= 0x050000
@@ -765,10 +747,8 @@ void BrowserWindow::loadConfig() {
 	view->setPlayer(HCPLAYER_NAME);
 #endif
 
-#ifdef SHOW_RELEASE_DIALOG
-	if (!shown_notes) {
-		QTimer::singleShot(3000, this, SLOT(showAboutRelease()));
-	}
+#ifdef USE_SITES
+	sites.load(settings);
 #endif
 }
 
