@@ -77,173 +77,202 @@
 <context>
     <name>BrowserWindow</name>
     <message>
-        <location filename="../browserwindow.cpp" line="125"/>
+        <location filename="../browserwindow.cpp" line="112"/>
         <source>Home</source>
         <translation>Maison</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="128"/>
+        <location filename="../browserwindow.cpp" line="115"/>
         <source>Navigation</source>
         <translation>Navigation</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="136"/>
+        <location filename="../browserwindow.cpp" line="123"/>
         <source>Zoom +</source>
         <translation>Zoom +</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="140"/>
+        <location filename="../browserwindow.cpp" line="127"/>
         <source>Zoom -</source>
         <translation>Zoom -</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="144"/>
+        <location filename="../browserwindow.cpp" line="131"/>
         <source>&amp;Quit</source>
         <translation>&amp;Quitter</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="147"/>
+        <location filename="../browserwindow.cpp" line="134"/>
         <source>&amp;Navigation</source>
         <translation>&amp;Navigation</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="159"/>
+        <location filename="../browserwindow.cpp" line="146"/>
         <source>&amp;View</source>
         <translation>&amp;Vue</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="160"/>
+        <location filename="../browserwindow.cpp" line="147"/>
         <source>Toolbar</source>
         <translation>Barre d&apos;outils</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="164"/>
+        <location filename="../browserwindow.cpp" line="151"/>
         <source>Statusbar</source>
         <translation>Barre de statut</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="168"/>
+        <location filename="../browserwindow.cpp" line="155"/>
         <source>&amp;Settings</source>
         <translation>&amp;Paramètres</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="176"/>
+        <location filename="../browserwindow.cpp" line="163"/>
         <source>&amp;Help</source>
         <translation>&amp;Aide</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="179"/>
-        <source>&amp;Update the YouTube code</source>
-        <translation>&amp;Mise à jour du code YouTube</translation>
+        <location filename="../browserwindow.cpp" line="167"/>
+        <source>&amp;Update YouTube playback support</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="185"/>
-        <source>About this &amp;release</source>
-        <translation>À propos de cette &amp;version</translation>
+        <location filename="../browserwindow.cpp" line="169"/>
+        <source>&amp;Install / Update YouTube playback support</source>
+        <translation>&amp;Installer / Mettre à jour le support de YouTube</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="190"/>
+        <location filename="../browserwindow.cpp" line="175"/>
         <source>&amp;About SMTube</source>
         <translation>&amp;À propos de SMTube</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="298"/>
+        <location filename="../browserwindow.cpp" line="296"/>
         <source>Download video using an external service</source>
         <translation>Télécharger la vidéo à l&apos;aide d&apos;un service externe</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="299"/>
+        <location filename="../browserwindow.cpp" line="297"/>
         <source>Download</source>
         <translation>Télécharger</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="527"/>
-        <source>Connection failed</source>
-        <translation>Connexion échouée</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="528"/>
-        <source>The video you requested needs to open a HTTPS connection.</source>
-        <translation>La vidéo demandée nécessite d&apos;ouvrir une connexion HTTPS.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="529"/>
-        <source>Unfortunately the OpenSSL component, required for it, is not available in your system.</source>
-        <translation>Malheureusement, le composant OpenSSL requis n&apos;est pas disponible sur votre système.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="534"/>
+        <location filename="../browserwindow.cpp" line="524"/>
         <source>No video found</source>
         <translation>Aucune vidéo trouvée</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="535"/>
+        <location filename="../browserwindow.cpp" line="525"/>
         <source>It wasn&apos;t possible to find the URL for this video.</source>
         <translation>Impossible de trouver l&apos;URL pour cette vidéo.</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="545"/>
-        <location filename="../browserwindow.cpp" line="553"/>
-        <source>Problems with YouTube</source>
-        <translation>Problèmes avec YouTube</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="546"/>
-        <location filename="../browserwindow.cpp" line="554"/>
-        <source>Unfortunately due to changes in YouTube, the video &apos;%1&apos; can&apos;t be played.</source>
-        <translation>Malheureusement, à cause de changements dans Youtube, il est impossible de lire la vidéo &apos;%1&apos;.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="547"/>
-        <source>Do you want to update the YouTube code? This may fix the problem.</source>
-        <translation>Voulez-vous mettre à jour le code Youtube ? Cela pourrait résoudre le problème.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="555"/>
-        <source>Maybe updating this application could fix the problem.</source>
-        <translation>Une mise à jour de l&apos;application pourrait résoudre ce problème.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="574"/>
-        <source>About this release</source>
-        <translation>À propos de cette version</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="575"/>
-        <source>Due to changes in YouTube, the old SMTube doesn&apos;t work anymore.</source>
-        <translation>A cause de changements dans YouTube, l&apos;ancien SMTube ne fonctionne plus.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="576"/>
-        <source>This is a new version of SMTube, written from scratch.</source>
-        <translation>Ceci est une nouvelle version de SMTube, réécrite totalement.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="577"/>
-        <source>Some functionality is not available yet.</source>
-        <translation>Quelques fonctionnalités ne sont toujours pas disponibles.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="579"/>
-        <source>Important:</source>
-        <translation>Important :</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="580"/>
-        <source>If the VEVO videos fail to play, please use the option %1 in the Help menu.</source>
-        <translation>Si les vidéos VEVO refusent de fonctionner, utilisez l&apos;option %1 dans le menu d&apos;Aide.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="581"/>
-        <source>Update the YouTube code</source>
-        <translation>Mettre à jour le code YouTube</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="284"/>
+        <location filename="../browserwindow.cpp" line="282"/>
         <source>Loading... %1%</source>
         <translation>Chargement... %1%</translation>
     </message>
 </context>
+<context>
+    <name>CodeDownloader</name>
+    <message>
+        <location filename="../codedownloader.cpp" line="49"/>
+        <source>Downloading...</source>
+        <translation>Téléchargement...</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="76"/>
+        <source>Connecting to %1</source>
+        <translation>Connexion à %1</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="145"/>
+        <source>The YouTube code has been installed successfully.</source>
+        <translation>Le code YouTube a été correctement installé.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="146"/>
+        <source>Installed version: %1</source>
+        <translation>Version installée : %1</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="147"/>
+        <source>Success</source>
+        <translation>Succès</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="152"/>
+        <location filename="../codedownloader.cpp" line="157"/>
+        <source>Error</source>
+        <translation>Erreur</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="152"/>
+        <source>It&apos;s not possible to save %1.</source>
+        <translation>Il est impossible d&apos;enregistrer %1.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="157"/>
+        <source>An error happened while downloading the file:&lt;br&gt;%1</source>
+        <translation>Une erreur est survenue lors du téléchargement du fichier :&lt;br&gt;%1</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="165"/>
+        <source>%1 failed to communicate with youtube-dl. Either it&apos;s not installed or it doesn&apos;t work correctly.</source>
+        <translation>%1 n&apos;a pas réussi à communiquer avec youtube-dl. Soit ce dernier n&apos;est pas installé, soit il ne fonctionne pas correctement.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="169"/>
+        <source>It wasn&apos;t possible to find the URL for this video.</source>
+        <translation type="unfinished">Impossible de trouver l&apos;URL pour cette vidéo.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="170"/>
+        <source>Maybe you need to update youtube-dl.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="175"/>
+        <location filename="../codedownloader.cpp" line="208"/>
+        <source>In order to play YouTube videos, %1 needs an external application called youtube-dl.</source>
+        <translation>Afin de lire les vidéos YouTube, %1 nécessite une application externe appelée youtube-dl.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="176"/>
+        <source>This component needs to be updated frequently.</source>
+        <translation>Ce composant doit être régulièrement mis à jour.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="177"/>
+        <source>You can update it just by reinstalling SMPlayer. The installer will download and install the very latest version.</source>
+        <translation>Vous pouvez le mettre à jour en réinstallant SMPlayer. L&apos;installateur téléchargera et installera la toute dernière version.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="179"/>
+        <source>Install / Update YouTube support</source>
+        <translation>Installer / Mettre à jour le support de YouTube</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="209"/>
+        <source>%1 can download and install this application for you.</source>
+        <translation>%1 peut télécharger et installer cette application pour vous.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="210"/>
+        <source>It will be downloaded from the official website and installed in %1.</source>
+        <translation>Il sera téléchargé depuis le site officiel et installé dans %1.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="211"/>
+        <source>Would you like to proceeed?</source>
+        <translation>Souhaitez-vous continuer ?</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="215"/>
+        <location filename="../codedownloader.cpp" line="218"/>
+        <source>Install YouTube support?</source>
+        <translation>Installer le support de YouTube ?</translation>
+    </message>
+</context>
 <context>
     <name>ConfigDialog</name>
     <message>
@@ -257,17 +286,22 @@
         <translation>&amp;Général</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="108"/>
+        <location filename="../configdialog.ui" line="127"/>
+        <source>A&amp;dd...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="166"/>
         <source>&amp;Players</source>
         <translation>&amp;Lecteurs</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="156"/>
+        <location filename="../configdialog.ui" line="214"/>
         <source>Add</source>
         <translation>Ajouter</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="121"/>
+        <location filename="../configdialog.ui" line="179"/>
         <source>Up</source>
         <translation>Haut</translation>
     </message>
@@ -282,37 +316,57 @@
         <translation>&amp;Qualité préférée :</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="167"/>
+        <location filename="../configdialog.ui" line="94"/>
+        <source>Sites</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="100"/>
+        <source>&amp;Site:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="120"/>
+        <source>Edi&amp;t...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="138"/>
+        <source>De&amp;lete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="225"/>
         <source>Delete</source>
         <translation>Suppression</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="191"/>
+        <location filename="../configdialog.ui" line="249"/>
         <source>Edit</source>
         <translation>Edition</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="204"/>
+        <location filename="../configdialog.ui" line="262"/>
         <source>A&amp;dd predefined players</source>
         <translation>A&amp;jout de lecteurs prédéfinis</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="240"/>
+        <location filename="../configdialog.ui" line="298"/>
         <source>&amp;Interface</source>
         <translation>&amp;Interface</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="248"/>
+        <location filename="../configdialog.ui" line="306"/>
         <source>&amp;Style:</source>
         <translation>&amp;Style :</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="284"/>
+        <location filename="../configdialog.ui" line="342"/>
         <source>Font:</source>
         <translation>Police :</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="298"/>
+        <location filename="../configdialog.ui" line="356"/>
         <source>C&amp;hange...</source>
         <translation>C&amp;hanger...</translation>
     </message>
@@ -327,12 +381,12 @@
         <translation>Télécharger la vidéo à l&apos;aide d&apos;un service &amp;externe</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="132"/>
+        <location filename="../configdialog.ui" line="190"/>
         <source>Down</source>
         <translation>Bas</translation>
     </message>
     <message>
-        <location filename="../configdialog.cpp" line="74"/>
+        <location filename="../configdialog.cpp" line="79"/>
         <source>Default</source>
         <translation>Défaut</translation>
     </message>
@@ -471,4 +525,27 @@
         <translation>Défaut</translation>
     </message>
 </context>
+<context>
+    <name>SiteDialog</name>
+    <message>
+        <location filename="../sitedialog.ui" line="14"/>
+        <source>Edit Site</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../sitedialog.ui" line="22"/>
+        <source>&amp;Name:</source>
+        <translation type="unfinished">&amp;Nom :</translation>
+    </message>
+    <message>
+        <location filename="../sitedialog.ui" line="39"/>
+        <source>&amp;Home page URL:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../sitedialog.ui" line="56"/>
+        <source>&amp;Search URL:</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
