@@ -77,173 +77,202 @@
 <context>
     <name>BrowserWindow</name>
     <message>
-        <location filename="../browserwindow.cpp" line="125"/>
+        <location filename="../browserwindow.cpp" line="112"/>
         <source>Home</source>
         <translation>Inicio</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="128"/>
+        <location filename="../browserwindow.cpp" line="115"/>
         <source>Navigation</source>
         <translation>Navegación</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="136"/>
+        <location filename="../browserwindow.cpp" line="123"/>
         <source>Zoom +</source>
         <translation>Ampliar</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="140"/>
+        <location filename="../browserwindow.cpp" line="127"/>
         <source>Zoom -</source>
         <translation>Reducir</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="144"/>
+        <location filename="../browserwindow.cpp" line="131"/>
         <source>&amp;Quit</source>
         <translation>&amp;Saír</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="147"/>
+        <location filename="../browserwindow.cpp" line="134"/>
         <source>&amp;Navigation</source>
         <translation>&amp;Navegación</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="159"/>
+        <location filename="../browserwindow.cpp" line="146"/>
         <source>&amp;View</source>
         <translation>&amp;Ver</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="160"/>
+        <location filename="../browserwindow.cpp" line="147"/>
         <source>Toolbar</source>
         <translation>Barra de ferramentas</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="164"/>
+        <location filename="../browserwindow.cpp" line="151"/>
         <source>Statusbar</source>
         <translation>Barra de estado</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="168"/>
+        <location filename="../browserwindow.cpp" line="155"/>
         <source>&amp;Settings</source>
         <translation>&amp;Axstes</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="176"/>
+        <location filename="../browserwindow.cpp" line="163"/>
         <source>&amp;Help</source>
         <translation>A&amp;xuda</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="179"/>
-        <source>&amp;Update the YouTube code</source>
-        <translation>&amp;Actualizar o código de YouTube</translation>
+        <location filename="../browserwindow.cpp" line="167"/>
+        <source>&amp;Update YouTube playback support</source>
+        <translation>&amp;Actualizar compatibilidade con YouTube</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="185"/>
-        <source>About this &amp;release</source>
-        <translation>Sobre esta &amp;publicación</translation>
+        <location filename="../browserwindow.cpp" line="169"/>
+        <source>&amp;Install / Update YouTube playback support</source>
+        <translation>&amp;Instalar / Actualizar compatibilidade para reprodución no YouTube</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="190"/>
+        <location filename="../browserwindow.cpp" line="175"/>
         <source>&amp;About SMTube</source>
         <translation>&amp;Sobre SMTube</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="298"/>
+        <location filename="../browserwindow.cpp" line="296"/>
         <source>Download video using an external service</source>
         <translation>Descargar o vídeo por medio dun servizo externo</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="299"/>
+        <location filename="../browserwindow.cpp" line="297"/>
         <source>Download</source>
         <translation>Descargar</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="527"/>
-        <source>Connection failed</source>
-        <translation>A conexión fallou</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="528"/>
-        <source>The video you requested needs to open a HTTPS connection.</source>
-        <translation>O vídeo solicitado precisa abrir a conexión HTTPS.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="529"/>
-        <source>Unfortunately the OpenSSL component, required for it, is not available in your system.</source>
-        <translation>Desafortunadamente o compoñente OpenSSL requirido non está dispoñíbel no sistema.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="534"/>
+        <location filename="../browserwindow.cpp" line="524"/>
         <source>No video found</source>
         <translation>Non se atopou ningún vídeo</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="535"/>
+        <location filename="../browserwindow.cpp" line="525"/>
         <source>It wasn&apos;t possible to find the URL for this video.</source>
         <translation>Non foi posíbel atopar a URL deste vídeo.</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="545"/>
-        <location filename="../browserwindow.cpp" line="553"/>
-        <source>Problems with YouTube</source>
-        <translation>Problemas con YouTube</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="546"/>
-        <location filename="../browserwindow.cpp" line="554"/>
-        <source>Unfortunately due to changes in YouTube, the video &apos;%1&apos; can&apos;t be played.</source>
-        <translation>Debido a cambios en YouTube non é posíbel reproducir o vídeo %1.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="547"/>
-        <source>Do you want to update the YouTube code? This may fix the problem.</source>
-        <translation>Quere actualizar o código de acceso a YouTube? Esta actualización podería solucionar o problema.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="555"/>
-        <source>Maybe updating this application could fix the problem.</source>
-        <translation>Actualizar o programa podeŕia solucionar o problema.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="574"/>
-        <source>About this release</source>
-        <translation>Sobre esta versión</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="575"/>
-        <source>Due to changes in YouTube, the old SMTube doesn&apos;t work anymore.</source>
-        <translation>Debido a cambios en YouTube, a versión vella de SMTube xa non funciona.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="576"/>
-        <source>This is a new version of SMTube, written from scratch.</source>
-        <translation>Esta é unha nova versión de SMTube escrita desde cero.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="577"/>
-        <source>Some functionality is not available yet.</source>
-        <translation>Algunhas funcionalidades aínda non están dispoñíbeis.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="579"/>
-        <source>Important:</source>
-        <translation>Importante:</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="580"/>
-        <source>If the VEVO videos fail to play, please use the option %1 in the Help menu.</source>
-        <translation>Se non consigue reproducir vídeos de VEVO, use a opción «%1» do menú de axuda.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="581"/>
-        <source>Update the YouTube code</source>
-        <translation>Actualizar o código para YouTube</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="284"/>
+        <location filename="../browserwindow.cpp" line="282"/>
         <source>Loading... %1%</source>
         <translation>Cargando... %1%</translation>
     </message>
 </context>
+<context>
+    <name>CodeDownloader</name>
+    <message>
+        <location filename="../codedownloader.cpp" line="49"/>
+        <source>Downloading...</source>
+        <translation>Descargando...</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="76"/>
+        <source>Connecting to %1</source>
+        <translation>Conectándose a %1</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="145"/>
+        <source>The YouTube code has been installed successfully.</source>
+        <translation>O código de Youtube instalouse correctamente.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="146"/>
+        <source>Installed version: %1</source>
+        <translation>Versión instalada: %1</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="147"/>
+        <source>Success</source>
+        <translation>Éxito</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="152"/>
+        <location filename="../codedownloader.cpp" line="157"/>
+        <source>Error</source>
+        <translation>Erro</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="152"/>
+        <source>It&apos;s not possible to save %1.</source>
+        <translation>Non é posíbel gardar %1.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="157"/>
+        <source>An error happened while downloading the file:&lt;br&gt;%1</source>
+        <translation>Aconteceu un erro mentres se descargaba: &lt;br&gt;%1</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="165"/>
+        <source>%1 failed to communicate with youtube-dl. Either it&apos;s not installed or it doesn&apos;t work correctly.</source>
+        <translation>%1 fallou tentando a comunicación co youtube-dl. Ou ben non está instalado ou non funciona correctamente.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="169"/>
+        <source>It wasn&apos;t possible to find the URL for this video.</source>
+        <translation type="unfinished">Non foi posíbel atopar a URL deste vídeo.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="170"/>
+        <source>Maybe you need to update youtube-dl.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="175"/>
+        <location filename="../codedownloader.cpp" line="208"/>
+        <source>In order to play YouTube videos, %1 needs an external application called youtube-dl.</source>
+        <translation>Con fin de reproducir vídeos de YouTube, %1 precisa dunha aplicación externa chamada youtube-dl.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="176"/>
+        <source>This component needs to be updated frequently.</source>
+        <translation>Este compoñente precisa actualizacións frecuentes.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="177"/>
+        <source>You can update it just by reinstalling SMPlayer. The installer will download and install the very latest version.</source>
+        <translation>Pode actualizalo simplemente reinstalando o SMPlayer. O instalador descargará e instalará a última versión.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="179"/>
+        <source>Install / Update YouTube support</source>
+        <translation>Instalar / Actualizar compatibilidade con YouTube</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="209"/>
+        <source>%1 can download and install this application for you.</source>
+        <translation>%1 pode descargar e instalar esta aplicación por vostede.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="210"/>
+        <source>It will be downloaded from the official website and installed in %1.</source>
+        <translation>Será descargada do sitio web oficial e instalarase en %1.</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="211"/>
+        <source>Would you like to proceeed?</source>
+        <translation>Desexa continuar?</translation>
+    </message>
+    <message>
+        <location filename="../codedownloader.cpp" line="215"/>
+        <location filename="../codedownloader.cpp" line="218"/>
+        <source>Install YouTube support?</source>
+        <translation>Desexa instalar a compatibilidade con YouTube?</translation>
+    </message>
+</context>
 <context>
     <name>ConfigDialog</name>
     <message>
@@ -257,17 +286,22 @@
         <translation>&amp;Xeral</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="108"/>
+        <location filename="../configdialog.ui" line="127"/>
+        <source>A&amp;dd...</source>
+        <translation>Enga&amp;dir...</translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="166"/>
         <source>&amp;Players</source>
         <translation>&amp;Reprodutores</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="156"/>
+        <location filename="../configdialog.ui" line="214"/>
         <source>Add</source>
         <translation>Engadir</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="121"/>
+        <location filename="../configdialog.ui" line="179"/>
         <source>Up</source>
         <translation>Arriba</translation>
     </message>
@@ -282,37 +316,57 @@
         <translation>&amp;Calidade preferida:</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="167"/>
+        <location filename="../configdialog.ui" line="94"/>
+        <source>Sites</source>
+        <translation>Sitios</translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="100"/>
+        <source>&amp;Site:</source>
+        <translation>&amp;Sitio:</translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="120"/>
+        <source>Edi&amp;t...</source>
+        <translation>Edi&amp;tar...</translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="138"/>
+        <source>De&amp;lete</source>
+        <translation>E&amp;liminar</translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="225"/>
         <source>Delete</source>
         <translation>Eliminar</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="191"/>
+        <location filename="../configdialog.ui" line="249"/>
         <source>Edit</source>
         <translation>Editar</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="204"/>
+        <location filename="../configdialog.ui" line="262"/>
         <source>A&amp;dd predefined players</source>
         <translation>Enga&amp;dir os reprodutores predefinidos</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="240"/>
+        <location filename="../configdialog.ui" line="298"/>
         <source>&amp;Interface</source>
         <translation>&amp;Interface</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="248"/>
+        <location filename="../configdialog.ui" line="306"/>
         <source>&amp;Style:</source>
         <translation>&amp;Estilo:</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="284"/>
+        <location filename="../configdialog.ui" line="342"/>
         <source>Font:</source>
         <translation>Tipo de letra:</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="298"/>
+        <location filename="../configdialog.ui" line="356"/>
         <source>C&amp;hange...</source>
         <translation>Ca&amp;mbiar...</translation>
     </message>
@@ -327,12 +381,12 @@
         <translation>Descargar os vídeos por medio dun servizo &amp;externo</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="132"/>
+        <location filename="../configdialog.ui" line="190"/>
         <source>Down</source>
         <translation>Abaixo</translation>
     </message>
     <message>
-        <location filename="../configdialog.cpp" line="74"/>
+        <location filename="../configdialog.cpp" line="79"/>
         <source>Default</source>
         <translation>Predeterminado</translation>
     </message>
@@ -471,4 +525,27 @@
         <translation>Predeterminado</translation>
     </message>
 </context>
+<context>
+    <name>SiteDialog</name>
+    <message>
+        <location filename="../sitedialog.ui" line="14"/>
+        <source>Edit Site</source>
+        <translation>Editar sitio</translation>
+    </message>
+    <message>
+        <location filename="../sitedialog.ui" line="22"/>
+        <source>&amp;Name:</source>
+        <translation>&amp;Nome:</translation>
+    </message>
+    <message>
+        <location filename="../sitedialog.ui" line="39"/>
+        <source>&amp;Home page URL:</source>
+        <translation>URL da páxin&amp;a de inicio:</translation>
+    </message>
+    <message>
+        <location filename="../sitedialog.ui" line="56"/>
+        <source>&amp;Search URL:</source>
+        <translation>URL de bu&amp;sca:</translation>
+    </message>
+</context>
 </TS>
